<?php

namespace Litecms\OurPorfolio\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\OurPorfolio\Models\OurPortfolio;

class OurPortfolioPolicy
{

    /**
     * Determine if the given user can view the our_portfolio.
     *
     * @param UserPolicy $user
     * @param OurPortfolio $our_portfolio
     *
     * @return bool
     */
    public function view(UserPolicy $user, OurPortfolio $our_portfolio)
    {
        if ($user->canDo('our_porfolio.our_portfolio.view') && $user->isAdmin()) {
            return true;
        }

        return $our_portfolio->user_id == user_id() && $our_portfolio->user_type == user_type();
    }

    /**
     * Determine if the given user can create a our_portfolio.
     *
     * @param UserPolicy $user
     * @param OurPortfolio $our_portfolio
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('our_porfolio.our_portfolio.create');
    }

    /**
     * Determine if the given user can update the given our_portfolio.
     *
     * @param UserPolicy $user
     * @param OurPortfolio $our_portfolio
     *
     * @return bool
     */
    public function update(UserPolicy $user, OurPortfolio $our_portfolio)
    {
        if ($user->canDo('our_porfolio.our_portfolio.edit') && $user->isAdmin()) {
            return true;
        }

        return $our_portfolio->user_id == user_id() && $our_portfolio->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given our_portfolio.
     *
     * @param UserPolicy $user
     * @param OurPortfolio $our_portfolio
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, OurPortfolio $our_portfolio)
    {
        return $our_portfolio->user_id == user_id() && $our_portfolio->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given our_portfolio.
     *
     * @param UserPolicy $user
     * @param OurPortfolio $our_portfolio
     *
     * @return bool
     */
    public function verify(UserPolicy $user, OurPortfolio $our_portfolio)
    {
        if ($user->canDo('our_porfolio.our_portfolio.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given our_portfolio.
     *
     * @param UserPolicy $user
     * @param OurPortfolio $our_portfolio
     *
     * @return bool
     */
    public function approve(UserPolicy $user, OurPortfolio $our_portfolio)
    {
        if ($user->canDo('our_porfolio.our_portfolio.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
