<?php

namespace Litecms\OurPorfolio\Providers;

use Illuminate\Support\ServiceProvider;

class OurPorfolioServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'our_porfolio');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'our_porfolio');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.our_porfolio', function ($app) {
            return $this->app->make('Litecms\OurPorfolio\OurPorfolio');
        });

                // Bind OurPortfolio to repository
        $this->app->bind(
            'Litecms\OurPorfolio\Interfaces\OurPortfolioRepositoryInterface',
            \Litecms\OurPorfolio\Repositories\Eloquent\OurPortfolioRepository::class
        );

        $this->app->register(\Litecms\OurPorfolio\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\OurPorfolio\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\OurPorfolio\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.our_porfolio'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/our_porfolio.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/our_porfolio')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/our_porfolio')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
